@@ -1,12 +1,13 @@
 import os
+import re
 import json
 import hashlib
 import argparse
 import subprocess
 import urllib.request
-from collections import defaultdict
 
 from pathlib import Path
+from collections import defaultdict
 
 # -------------------------------------------------------------------------
 # Alias management
@@ -18,7 +19,15 @@ RC_FILES = {
     "zsh": ".zshrc"
 }
 
-VERSION = "1.0.0"
+
+def _get_version() -> str:
+    here = os.path.dirname(__name__)
+    init_file = os.path.join(here, "__init__.py")
+    with open(init_file, "r") as f:
+        content = f.read()
+
+    return re.match(r'(__version__)([\s]+=[\s]+)(\")([\.\d]+)(\")',
+                    content).group(4)
 
 
 class CatalogCheckSumError(Exception):
@@ -84,9 +93,11 @@ def get_catalog() -> List[dict] or CatalogCheckSumError:
             urllib.request.urlopen(CATALOG_CHECK_SUM) as check_sum:
         raw_content = catalog.read()
         remote_catalog_check_sum = check_sum.read()
+        if type(remote_catalog_check_sum) is bytes:
+            remote_catalog_check_sum = remote_catalog_check_sum.decode("UTF-8")
 
         h = hashlib.sha512()
-        h.update(raw_content.encode("UTF-8"))
+        h.update(raw_content)
         check_sum = h.hexdigest()
 
         if check_sum != remote_catalog_check_sum:
@@ -125,7 +136,7 @@ def print_table(content: List[Tuple[str, str]],
             print(" | ", end="")
             print(f"{head[1]}", end="")
             print(
-                f"{' ' * (width - (max_key_len + len(head[1]) + 5 ))}",
+                f"{' ' * (width - (max_key_len + len(head[1]) + 5))}",
                 end="")
             print(" |")
         else:
@@ -192,7 +203,6 @@ def list_packages(args: argparse.Namespace):
 
 
 def install_package(args: argparse.Namespace):
-
     def build_alias_cmd(cmd: str, docker_image: str):
         return f'''alias {cmd}="docker run --rm -i {docker_image}"'''
 
@@ -203,7 +213,8 @@ def install_package(args: argparse.Namespace):
     catalog = get_catalog()
 
     # Find tool
-    if not (tool := search_in_catalog(catalog, tool_name)):
+    tool = search_in_catalog(catalog, tool_name)
+    if not tool:
         print(f"[!] Can't find tool named '{tool_name}'")
         exit(1)
 
@@ -222,9 +233,13 @@ def install_package(args: argparse.Namespace):
                             stdout=subprocess.PIPE,
                             shell=True)
 
-    # while line := proc.stdout.poll():
     print("")
-    while line := proc.stdout.readline():
+    while 1:
+        line = proc.stdout.readline()
+
+        if not line:
+            break
+
         print("   ", line.decode("UTF-8"), end="")
     print("")
 
@@ -337,7 +352,8 @@ def info_package(args: argparse.Namespace):
     catalog = get_catalog()
 
     # Find tool
-    if not (tool := search_in_catalog(catalog, tool_name)):
+    tool = search_in_catalog(catalog, tool_name)
+    if tool:
         print(f"[!] Can't find tool named '{tool_name}'")
         exit(1)
 
@@ -376,7 +392,6 @@ def describe_env(args: argparse.Namespace):
 
 
 def list_environments(args: argparse.Namespace):
-
     base = Path().home().joinpath(".apicheck_manager")
     meta = base.joinpath("meta.json")
 
@@ -413,7 +428,7 @@ def main():
         "activate": activate_env,
         "describe": describe_env,
         "envs": list_environments,
-        "version": lambda x: print(f"\nCurrent version: {VERSION}\n"),
+        "version": lambda x: print(f"\nCurrent version: {_get_version()}\n"),
     }
 
     parser = argparse.ArgumentParser(description='APICheck Manager')
